@@ -515,13 +515,12 @@ e_webdav_discover_setup_proxy_resolver (EWebDAVSession *webdav,
 /**
  * e_webdav_discover_sources:
  * @source: an #ESource from which to take connection details
- * @url_use_path: (allow-none): optional URL override, or %NULL
+ * @url_use_path: (nullable): optional URL override, or %NULL
  * @only_supports: bit-or of EWebDAVDiscoverSupports, to limit what type of sources to search
- * @credentials: (allow-none): credentials to use for authentication to the server
- * @cancellable: (allow-none): optional #GCancellable object, or %NULL
- * @callback: (scope async): a #GAsyncReadyCallback to call when the request
- *            is satisfied
- * @user_data: (closure): data to pass to the callback function
+ * @credentials: (nullable): credentials to use for authentication to the server
+ * @cancellable: optional #GCancellable object, or %NULL
+ * @callback: a #GAsyncReadyCallback to call when the request is satisfied
+ * @user_data: data to pass to the callback function
  *
  * Asynchronously runs discovery of the WebDAV sources (CalDAV and CardDAV), eventually
  * limited by the @only_supports filter, which can be %E_WEBDAV_DISCOVER_SUPPORTS_NONE
@@ -558,9 +557,8 @@ e_webdav_discover_sources (ESource *source,
  * @ref_source_func: (nullable) (scope async): optional callback to use to get an ESource
  * @ref_source_func_user_data: (nullable): user data for @ref_source_func
  * @cancellable: optional #GCancellable object, or %NULL
- * @callback: (scope async): a #GAsyncReadyCallback to call when the request
- *            is satisfied
- * @user_data: (closure): data to pass to the callback function
+ * @callback: a #GAsyncReadyCallback to call when the request is satisfied
+ * @user_data: data to pass to the callback function
  *
  * This is the same as e_webdav_discover_sources(), it only allows to
  * provide a callback function (with its user_data), to reference an additional
@@ -603,16 +601,16 @@ e_webdav_discover_sources_full (ESource *source,
  * e_webdav_discover_sources_finish:
  * @source: an #ESource on which the operation was started
  * @result: a #GAsyncResult
- * @out_certificate_pem: (out) (allow-none): optional return location
+ * @out_certificate_pem: (out) (optional): optional return location
  *   for a server SSL certificate in PEM format, when the operation failed
  *   with an SSL error
- * @out_certificate_errors: (out) (allow-none): optional #GTlsCertificateFlags,
+ * @out_certificate_errors: (out) (optional): optional #GTlsCertificateFlags,
  *   with certificate error flags when the operation failed with SSL error
- * @out_discovered_sources: (out) (element-type EWebDAVDiscoveredSource): a #GSList
+ * @out_discovered_sources: (out) (optional) (element-type EWebDAVDiscoveredSource): a #GSList
  *   of all discovered sources
- * @out_calendar_user_addresses: (out) (allow-none) (element-type utf8): a #GSList of
+ * @out_calendar_user_addresses: (out) (optional) (element-type utf8): a #GSList of
  *   all discovered mail addresses for calendar sources
- * @error: (allow-none): return location for a #GError, or %NULL
+ * @error: return location for a #GError, or %NULL
  *
  * Finishes the operation started with e_webdav_discover_sources(). If an
  * error occurred, the function will set @error and return %FALSE. The function
@@ -699,20 +697,20 @@ e_webdav_discover_maybe_replace_auth_error (GError **target,
 /**
  * e_webdav_discover_sources_sync:
  * @source: an #ESource from which to take connection details
- * @url_use_path: (allow-none): optional URL override, or %NULL
+ * @url_use_path: (nullable): optional URL override, or %NULL
  * @only_supports: bit-or of EWebDAVDiscoverSupports, to limit what type of sources to search
- * @credentials: (allow-none): credentials to use for authentication to the server
- * @out_certificate_pem: (out) (allow-none): optional return location
+ * @credentials: (nullable): credentials to use for authentication to the server
+ * @out_certificate_pem: (out) (optional): optional return location
  *   for a server SSL certificate in PEM format, when the operation failed
  *   with an SSL error
- * @out_certificate_errors: (out) (allow-none): optional #GTlsCertificateFlags,
+ * @out_certificate_errors: (out) (optional): optional #GTlsCertificateFlags,
  *   with certificate error flags when the operation failed with SSL error
- * @out_discovered_sources: (out) (element-type EWebDAVDiscoveredSource): a #GSList
+ * @out_discovered_sources: (out) (optional) (element-type EWebDAVDiscoveredSource): a #GSList
  *   of all discovered sources
- * @out_calendar_user_addresses: (out) (allow-none) (element-type utf8): a #GSList of
+ * @out_calendar_user_addresses: (out) (optional) (element-type utf8): a #GSList of
  *   all discovered mail addresses for calendar sources
- * @cancellable: (allow-none): optional #GCancellable object, or %NULL
- * @error: (allow-none): return location for a #GError, or %NULL
+ * @cancellable: optional #GCancellable object, or %NULL
+ * @error: return location for a #GError, or %NULL
  *
  * Synchronously runs discovery of the WebDAV sources (CalDAV and CardDAV), eventually
  * limited by the @only_supports filter, which can be %E_WEBDAV_DISCOVER_SUPPORTS_NONE
@@ -774,6 +772,14 @@ e_webdav_discover_cmp_sources (gconstpointer ptr1,
 	return g_strcmp0 (source1->display_name, source2->display_name);
 }
 
+static gboolean
+e_webdav_discover_is_fatal_error (const GError *error)
+{
+	return g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED) ||
+	       g_error_matches (error, G_IO_ERROR, G_IO_ERROR_TIMED_OUT) ||
+	       g_error_matches (error, G_IO_ERROR, G_IO_ERROR_FAILED);
+}
+
 /**
  * e_webdav_discover_sources_full_sync:
  * @source: an #ESource from which to take connection details
@@ -782,14 +788,14 @@ e_webdav_discover_cmp_sources (gconstpointer ptr1,
  * @credentials: (nullable): credentials to use for authentication to the server
  * @ref_source_func: (nullable) (scope call): optional callback to use to get an ESource
  * @ref_source_func_user_data: (nullable): user data for @ref_source_func
- * @out_certificate_pem: (out) (nullable): optional return location
+ * @out_certificate_pem: (out) (optional): optional return location
  *   for a server SSL certificate in PEM format, when the operation failed
  *   with an SSL error
- * @out_certificate_errors: (out) (nullable): optional #GTlsCertificateFlags,
+ * @out_certificate_errors: (out) (optional): optional #GTlsCertificateFlags,
  *   with certificate error flags when the operation failed with SSL error
- * @out_discovered_sources: (out) (element-type EWebDAVDiscoveredSource): a #GSList
+ * @out_discovered_sources: (out) (optional) (element-type EWebDAVDiscoveredSource): a #GSList
  *   of all discovered sources
- * @out_calendar_user_addresses: (out) (nullable) (element-type utf8): a #GSList of
+ * @out_calendar_user_addresses: (out) (optional) (element-type utf8): a #GSList of
  *   all discovered mail addresses for calendar sources
  * @cancellable: optional #GCancellable object, or %NULL
  * @error: return location for a #GError, or %NULL
@@ -876,6 +882,7 @@ e_webdav_discover_sources_full_sync (ESource *source,
 	if (!g_cancellable_set_error_if_cancelled (cancellable, error)) {
 		WebDAVDiscoverData wdd;
 		gchar *uri;
+		gboolean fatal_error;
 		GError *local_error = NULL;
 
 		wdd.covered_hrefs = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
@@ -892,7 +899,9 @@ e_webdav_discover_sources_full_sync (ESource *source,
 
 		g_free (uri);
 
-		if (!g_cancellable_is_cancelled (cancellable) && !wdd.calendars &&
+		fatal_error = e_webdav_discover_is_fatal_error (local_error);
+
+		if (!fatal_error && !g_cancellable_is_cancelled (cancellable) && !wdd.calendars &&
 		    ((only_supports & (~CUSTOM_SUPPORTS_FLAGS)) == E_WEBDAV_DISCOVER_SUPPORTS_NONE ||
 		    (only_supports & (E_WEBDAV_DISCOVER_SUPPORTS_EVENTS | E_WEBDAV_DISCOVER_SUPPORTS_MEMOS | E_WEBDAV_DISCOVER_SUPPORTS_TASKS)) != 0) &&
 		    (!soup_uri_get_path (soup_uri) || !strstr (soup_uri_get_path (soup_uri), "/.well-known/"))) {
@@ -913,6 +922,8 @@ e_webdav_discover_sources_full_sync (ESource *source,
 
 			g_free (uri);
 
+			fatal_error = e_webdav_discover_is_fatal_error (local_error_2nd);
+
 			soup_uri_set_path (soup_uri, saved_path);
 			g_free (saved_path);
 
@@ -924,7 +935,7 @@ e_webdav_discover_sources_full_sync (ESource *source,
 			wdd.error = NULL;
 		}
 
-		if (!g_cancellable_is_cancelled (cancellable) &&
+		if (!fatal_error && !g_cancellable_is_cancelled (cancellable) &&
 		    ((only_supports & (~CUSTOM_SUPPORTS_FLAGS)) == E_WEBDAV_DISCOVER_SUPPORTS_NONE ||
 		    (only_supports & (E_WEBDAV_DISCOVER_SUPPORTS_WEBDAV_NOTES)) != 0) &&
 		    (!soup_uri_get_path (soup_uri) || !strstr (soup_uri_get_path (soup_uri), "/.well-known/"))) {
@@ -945,6 +956,8 @@ e_webdav_discover_sources_full_sync (ESource *source,
 
 			g_free (uri);
 
+			fatal_error = e_webdav_discover_is_fatal_error (local_error_2nd);
+
 			soup_uri_set_path (soup_uri, saved_path);
 			g_free (saved_path);
 
@@ -956,7 +969,7 @@ e_webdav_discover_sources_full_sync (ESource *source,
 			wdd.error = NULL;
 		}
 
-		if (!g_cancellable_is_cancelled (cancellable) && !wdd.addressbooks &&
+		if (!fatal_error && !g_cancellable_is_cancelled (cancellable) && !wdd.addressbooks &&
 		    ((only_supports & (~CUSTOM_SUPPORTS_FLAGS)) == E_WEBDAV_DISCOVER_SUPPORTS_NONE ||
 		    (only_supports & (E_WEBDAV_DISCOVER_SUPPORTS_CONTACTS)) != 0) &&
 		    (!soup_uri_get_path (soup_uri) || !strstr (soup_uri_get_path (soup_uri), "/.well-known/"))) {
@@ -980,6 +993,8 @@ e_webdav_discover_sources_full_sync (ESource *source,
 			soup_uri_set_path (soup_uri, saved_path);
 			g_free (saved_path);
 
+			fatal_error = e_webdav_discover_is_fatal_error (local_error_2nd);
+
 			if (e_webdav_discover_maybe_replace_auth_error (&local_error, &local_error_2nd))
 				success = FALSE;
 
@@ -990,26 +1005,33 @@ e_webdav_discover_sources_full_sync (ESource *source,
 
 		if (wdd.calendars || wdd.addressbooks) {
 			success = TRUE;
+			fatal_error = FALSE;
 			g_clear_error (&local_error);
 		} else if (local_error) {
+			success = FALSE;
 			g_propagate_error (error, local_error);
 		}
 
-		if (out_discovered_sources) {
+		if (out_discovered_sources && !fatal_error) {
 			if (only_supports == E_WEBDAV_DISCOVER_SUPPORTS_NONE ||
 			    (only_supports & E_WEBDAV_DISCOVER_SUPPORTS_CALENDAR_AUTO_SCHEDULE) != 0) {
 				GSList *link;
 
-				for (link = wdd.calendars; link && !g_cancellable_is_cancelled (cancellable); link = g_slist_next (link)) {
+				for (link = wdd.calendars; link && !fatal_error && !g_cancellable_is_cancelled (cancellable); link = g_slist_next (link)) {
 					EWebDAVDiscoveredSource *discovered = link->data;
 					GHashTable *allows = NULL, *capabilities = NULL;
 
+					local_error = NULL;
+
 					if (discovered && discovered->href &&
-					    e_webdav_session_options_sync (webdav, discovered->href, &capabilities, &allows, cancellable, NULL)) {
+					    e_webdav_session_options_sync (webdav, discovered->href, &capabilities, &allows, cancellable, &local_error)) {
 						if (capabilities && g_hash_table_contains (capabilities, E_WEBDAV_CAPABILITY_CALENDAR_AUTO_SCHEDULE))
 							discovered->supports |= E_WEBDAV_DISCOVER_SUPPORTS_CALENDAR_AUTO_SCHEDULE;
 					}
 
+					fatal_error = e_webdav_discover_is_fatal_error (local_error);
+					g_clear_error (&local_error);
+
 					if (allows)
 						g_hash_table_destroy (allows);
 
