@@ -42,12 +42,14 @@
 #include <libedataserver/e-oauth2-service-base.h>
 #include <libedataserver/e-oauth2-service-google.h>
 #include <libedataserver/e-oauth2-service-outlook.h>
+#include <libedataserver/e-oauth2-service-yahoo.h>
 #include <libedataserver/e-oauth2-services.h>
 #include <libedataserver/e-operation-pool.h>
 #include <libedataserver/e-proxy.h>
 #include <libedataserver/e-secret-store.h>
 #include <libedataserver/e-sexp.h>
 #include <libedataserver/e-soup-auth-bearer.h>
+#include <libedataserver/e-soup-logger.h>
 #include <libedataserver/e-soup-session.h>
 #include <libedataserver/e-soup-ssl-trust.h>
 #include <libedataserver/e-source-address-book.h>
@@ -104,6 +106,8 @@
 #include <libedataserver/e-xml-utils.h>
 #include <libedataserver/eds-version.h>
 
+#include <libedataserver/e-dataserver-autocleanups.h>
+
 #undef __LIBEDATASERVER_H_INSIDE__
 
 #endif /* LIBEDATASERVER_H */
